@@ -2,7 +2,7 @@
 
 -- |
 -- Module      :  CLI.Arguments
--- Copyright   :  (c) OleksandrZhabenko 2021
+-- Copyright   :  (c) OleksandrZhabenko 2021-2022
 -- License     :  MIT
 -- Stability   :  Experimental
 -- Maintainer  :  olexandr543@yahoo.com
@@ -12,8 +12,10 @@
 module CLI.Arguments where
 
 import Data.Monoid (mappend)
+import Data.Maybe (fromJust)
 import GHC.Arr
 import Data.List (sortBy)
+import qualified Data.Foldable as F
 
 data Arguments =
   A String
@@ -376,3 +378,72 @@ takeAsArrSortedBy
   -> Array Int Arguments
 takeAsArrSortedBy = takeABCsArrSortedBy (takeArgsSortedBy (\x -> notNullArguments x && isA x))
 {-# INLINABLE takeAsArrSortedBy #-}
+
+-------------------------------------------------------------------------------
+
+oneA
+ :: (F.Foldable t) => String -> t Arguments -> Bool
+oneA xs ys = F.any (\(A ts) -> ts == xs) ys
+
+oneB
+ :: (F.Foldable t) => String -> t Arguments -> Bool
+oneB xs ys = F.any (\(B _ zs _) -> zs == xs) ys
+
+oneC
+ :: (F.Foldable t) => String -> t Arguments -> Bool
+oneC xs ys = F.any (\(C zs _) -> zs == xs) ys
+
+listA
+ :: (F.Foldable t) => [String] -> t Arguments -> Bool
+listA xss ys
+  | null xss = False
+  | otherwise = F.any (\(A ts) -> ts `elem` xss) ys
+
+listB
+ :: (F.Foldable t) => [String] -> t Arguments -> Bool
+listB xss ys
+  | null xss = False
+  | otherwise = F.any (\(B _ zs _) -> zs `elem` xss) ys
+
+listC
+ :: (F.Foldable t) => [String] -> t Arguments -> Bool
+listC xss ys
+  | null xss = False
+  | otherwise = F.any (\(C zs _) -> zs `elem` xss) ys
+
+getA
+ :: (F.Foldable t) => String -> t Arguments -> String
+getA xs ys
+  | oneA xs ys = (\(A ts) -> ts) . fromJust . F.find (\(A rs) -> rs == xs) $ ys
+  | otherwise = []
+
+getB
+ :: (F.Foldable t) => String -> t Arguments -> [String]
+getB xs ys
+  | oneB xs ys =  (\(B _ _ yss) -> yss) . fromJust . F.find (\(B _ zs _) -> zs == xs) $ ys
+  | otherwise = []
+
+getC
+ :: (F.Foldable t) => String -> t Arguments -> [String]
+getC xs ys
+  | oneC xs ys = (\(C _ yss) -> yss) . fromJust . F.find (\(C zs _) -> zs == xs) $ ys
+  | otherwise = []
+
+getLstA
+ :: (F.Foldable t) => [String] -> t Arguments -> [String]
+getLstA xss ys
+  | listA xss ys = filter (not . null) . map (\xs -> getA xs ys) $ xss
+  | otherwise = []
+
+getLstB
+ :: (F.Foldable t) => [String] -> t Arguments -> [[String]]
+getLstB xss ys
+  | listB xss ys = filter (not . null) . map (\xs -> getB xs ys) $ xss
+  | otherwise = []
+
+getLstC
+ :: (F.Foldable t) => [String] -> t Arguments -> [[String]]
+getLstC xss ys
+  | listC xss ys = filter (not . null) . map (\xs -> getC xs ys) $ xss
+  | otherwise = []
+
